==> haskell-aeson-compat-0.3.7.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.7.1
id: aeson-compat-0.3.7.1-7uDGTmCvIOH6KOpreK3LM
key: aeson-compat-0.3.7.1-7uDGTmCvIOH6KOpreK3LM
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.Compat
abi: 6f58424a376264e9962f3d2b7d99fba5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-compat-0.3.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-compat-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aeson-compat-0.3.7.1
hs-libraries: HSaeson-compat-0.3.7.1-7uDGTmCvIOH6KOpreK3LM
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    aeson-1.2.4.0-9TsMr8JCMWWAuTOIqOHJIi
    attoparsec-0.13.2.2-LZeWrUF9jJCLKiulgivlMd
    attoparsec-iso8601-1.0.0.0-LpChzQ4p5QxIaqUISA5a1j
    bytestring-0.10.8.2 containers-0.5.10.2
    exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             aeson-1.2.4.0-9TsMr8JCMWWAuTOIqOHJIi=678f7baab8d88792435c407def5321e2
             attoparsec-0.13.2.2-LZeWrUF9jJCLKiulgivlMd=e2a8304e8e3d2a4e2c1322de5747978c
             attoparsec-iso8601-1.0.0.0-LpChzQ4p5QxIaqUISA5a1j=0c8f44cd7b1a65accecb84f23a9c34fe
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO=6e538d6297179a35ae8f400426125b37
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.7.1-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.7.1
id: aeson-compat-0.3.7.1-BghK4W3KE7jIEUoUCXEpHq
key: aeson-compat-0.3.7.1-BghK4W3KE7jIEUoUCXEpHq
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.Compat
abi: cc3f30a155fb055fe21118c78a4e0c85
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-compat-0.3.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-compat-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/aeson-compat-0.3.7.1
hs-libraries: HSaeson-compat-0.3.7.1-BghK4W3KE7jIEUoUCXEpHq
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    aeson-1.2.4.0-LfzbQdLtEh8Dr9TGmQripa
    attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm
    attoparsec-iso8601-1.0.0.0-5uWH5TV26vU2BQHkozfJoB
    bytestring-0.10.8.2 containers-0.5.10.2
    exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             aeson-1.2.4.0-LfzbQdLtEh8Dr9TGmQripa=4a8adb8dc6357086bd8deb5249fe98d7
             attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm=dbf2a2c6556965dad88a2349e873212b
             attoparsec-iso8601-1.0.0.0-5uWH5TV26vU2BQHkozfJoB=e5814f240dbddf40ff1b9f7569cf416e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             exceptions-0.8.3-LdkvhAEH3VPBvXQLZp0mCT=f624bf973f8eeff6578fe95732b4e11a
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             scientific-0.3.5.2-IWSZVQGiPwx2zNrAPvmBEO=6e538d6297179a35ae8f400426125b37
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
